
Հարգելի *{{ data.name | safe }}*,

Շնորհակալություն մեզ հետ կապ հաստատելու համար: {{ created | safe }} դուք ուղարկել եք հետևյալ հաղորդագրությունը.

**{{ data.message | safe }}**

Մեր խորհրդատուներից մեկը որքան հնարավոր է շուտ կկապվի ձեզ հետ։

Հարգանքով,

*Թիմ*
